module.exports = function(grunt) {

// Project configuration.
grunt.initConfig({
	pkg: grunt.file.readJSON('package.json'),

	// VARIABLES
	jsFiles: [
		'.assets/js/app.js',
		'.assets/js/services/*.js',
		'.assets/js/controllers/*.js',
		'.assets/js/directives/*.js',
		'.assets/js/directives/articles/*.js',
		'.assets/js/filters/*.js'
		],
	vendorFiles: [
		// managed by bower
		'.assets/vendor/jquery/dist/jquery.js',
		'.assets/vendor/momentjs/moment.js',
		'.assets/vendor/momentjs/locale/ro.js',
		'.assets/vendor/angular/angular.js',
		'.assets/vendor/angular-animate/angular-animate.js',
		'.assets/vendor/angular-resource/angular-resource.js',
        '.assets/vendor/angular-cookies/angular-cookies.js',
		'.assets/vendor/angular-route/angular-route.js',
		'.assets/vendor/angular-sanitize/angular-sanitize.js',
		'.assets/vendor/angular-touch/angular-touch.js',
        '.assets/vendor/hammerjs/hammer.js',
		'.assets/vendor/ryanmullins-angular-hammer/angular.hammer.js',
		'.assets/vendor/angular-carousel/dist/angular-carousel.js'
	],

	// COMPASS
	compass: {
		dist: {
			options: {
				sassDir: '.assets/scss',
				cssDir: 'css',
				environment: 'production'
			}
		},
		dev: {
			options: {
				sassDir: '.assets/scss',
				cssDir: 'css'
			}
		}
	},

	// JSHINT
	jshint: {
    	all: [
    		'Gruntfile.js',
    		'.assets/js/**/*.js'
    	]
	},

	// UGLIFY
	uglify: {
		dev: {
			files: {
				'js/main.min.js': ['js/vendor.js', 'js/scripts.js']
			}
		}
	},
	concat: {
		options: {
			separator: ';',
		},
		vendor: {
			src: '<%= vendorFiles %>',
			dest: 'js/vendor.js',
		},
		scripts: {
			src: '<%= jsFiles %>',
			dest: 'js/scripts.js',
		},
	},
	connect: {
		server: {
			options: {
				port: 9001,
				base: '.',
				hostname: 'localhost',
				keepalive: true,
				open: true
			}
		}
	},
	watch: {
		scripts: {
			files: '<%= jsFiles %>',
			tasks: ['jshint:all', 'concat:scripts']
		},
		styles: {
			files: '.assets/scss/**/*.scss',
			tasks: ['compass:dev']
		}
	}
});

// Load the plugin that provides the "uglify" task.
grunt.loadNpmTasks('grunt-contrib-uglify');
grunt.loadNpmTasks('grunt-contrib-compass');
grunt.loadNpmTasks('grunt-contrib-connect');
grunt.loadNpmTasks('grunt-contrib-copy');
grunt.loadNpmTasks('grunt-contrib-jshint');
grunt.loadNpmTasks('grunt-contrib-uglify');
grunt.loadNpmTasks('grunt-contrib-concat');
grunt.loadNpmTasks('grunt-contrib-watch');

// Default task(s).
grunt.registerTask('default', ['compass:dev', 'jshint:all', 'concat:vendor', 'concat:scripts']);

};