

// define the main app
var adhApp = angular.module('adhApp', [
	'ngRoute',
	'ngAnimate',
	'ngCookies',
	'ngSanitize',
	'hmTouchEvents',
	'angular-carousel'
]);

// app config, routing
adhApp.config(['$routeProvider', function($routeProvider) {

	$routeProvider
		.when('/', {
			controller: 'routeCtrl',
			template: '<div></div>'
		})
		.when('/list/:category?/:subcategory?', {
			controller: 'listingCtrl',
			templateUrl: 'templates/views/list-base.html'
		})
		.when('/auth/:step?', {
			controller: 'authCtrl',
			templateUrl: 'templates/views/auth.html'
		})
		.when('/article/:identifier/:comments?', {
			controller: 'articleCtrl',
			templateUrl: 'templates/views/article-base.html'
		})
		.when('/video/:identifier', {
			controller: 'videoCtrl',
			templateUrl: 'templates/views/video.html'
		})
		.when('/search', {
			controller: 'searchCtrl',
			templateUrl: 'templates/views/search.html'
		})
		.when('/settings', {
			controller: 'settingsCtrl',
			templateUrl: 'templates/views/settings.html'
		})
		.otherwise({
			redirectTo: '/404'
		});

}]);

adhApp.config(['$httpProvider', function($httpProvider) {
		$httpProvider.defaults.withCredentials = true;
	}
]);

adhApp.config(function($sceDelegateProvider) {
	$sceDelegateProvider.resourceUrlWhitelist([
		// Allow same origin resource loads.
		'self',
		// Allow loading from our assets domain.  Notice the difference between * and **.
		'http://mapi.adevarul.ro/**'
	]);
});;adhApp.factory('apiFactory', function($http) {

	var baseURL = 'http://mapi.adevarul.ro';

	var api = {
		getSection: function(requestType) {
			if (requestType === 'home') {
				return $http.get(baseURL + '/section/');
			} else if (requestType.category === 'blogs') {
				return $http.get(baseURL + '/search/?type=article&blog=true&sort=publishDate:desc');
			} else if (requestType.category === 'live') {
				return $http.get(baseURL + '/search/?type=video&limit=25&sort=publishDate:desc&tags=with:adevarul%20live');
			} else if (requestType.category === 'latest') {
				return $http.get(baseURL + '/search/?type=article&limit=25&sort=publishDate:desc');
			} else {
				if (requestType.subcategory === undefined) {
					return $http.get(baseURL + '/section/?identifier=/' + requestType.category + '/');
				} else {
					return $http.get(baseURL + '/section/?identifier=/' + requestType.category + '/' + requestType.subcategory + '/');
				}
			}
		},
		getSectionList: function(){
			return $http.get(baseURL + '/sections/');
		},
		postKarma: function(identifier, karmaType) {
			return $http.post(baseURL + '/karma/?identifier=' + identifier, {like: karmaType});
		},
		search: function(term) {
			return $http.get(baseURL + '/search/?text=' + term + '&type=article');
		},
		getContent: function(identifier, vWidth, vHeight) {
			if (!vWidth && !vHeight) {
				return $http.get(baseURL + '/content/?identifier=' + identifier);
			} else {
				return $http.get(baseURL + '/content/?identifier=' + identifier + '&vWidth=' + vWidth + '&vHeight=' + vHeight);
			}

		},
		getBlogs: function() {
			return $http.get(baseURL + '/search/?type=article&blog=true&sort=publishDate:desc');
		},
		getLive: function(section) {
			if (section === undefined || section === 'locale' || section === 'moldova') {
				return $http.get(baseURL + '/search/?type=video&limit=25&sort=publishDate:desc&tags=with:adevarul%20live');
			} else {
				return $http.get(baseURL + '/search/?type=video&limit=25&sort=publishDate:desc&tags=with:adevarul%20live&section=/' + section + '/');
			}

		},
		auth: {
			login: function(email, password) {
				return $http.post(baseURL + '/auth/?action=login', {email: email, password: password});
			},
			register: function(email, password, firstName, lastName, agreeTOS) {
				return $http.post(baseURL + '/auth/?action=register', {
					email: email,
					password: password,
					rePassword: password,
					firstName: firstName,
					lastName: lastName,
					agree_tos: agreeTOS
				});
			},
			status: function() {
				return $http.get(baseURL + '/auth/?action=check');
			},
			logout: function() {
				return $http.get(baseURL + '/auth/?action=logout');
			}
		},
		comments: {
			get: function(identifier) {
				return $http.get(baseURL + '/comments/?identifier=' + identifier);
			},
			post: function(identifier, body, replyTo) {
				if (replyTo) {
					return $http.post(baseURL + '/comments/?action=comment&identifier=' + identifier, {
						body: body,
						replyTo: replyTo
					});
				} else {
					return $http.post(baseURL + '/comments/?action=comment&identifier=' + identifier, {
						body: body
					});
				}

			},
			vote: function(identifier, like) {
				return $http.post(baseURL + '/comments/?identifier=' + identifier + '&action=vote', {like: like});
			}
		}
	};

	return api;


});;adhApp.factory('dataFactory', function() {

	// if sections already exist in localstorage grab them
	var sections;
	if (localStorage.getItem('sections') !== null) {
		sections = JSON.parse(localStorage.getItem('sections'));
	} else {
		sections = null;
	}

	var viewMode;
	// if not present set default view to list
	if (localStorage.getItem('viewMode') === null) {
		if($(window).outerWidth() < 480) {
			localStorage.setItem('viewMode', 'card');
			viewMode = 'card';
		} else {
			localStorage.setItem('viewMode', 'tablet');
			viewMode = 'tablet';
		}

	} else {
		viewMode = localStorage.getItem('viewMode');
	}

	var auth;
	// check localstorage for current user data, second check (with API) is in initCtrl
	if(localStorage.getItem('user') !== null) {
		auth = JSON.parse(localStorage.getItem('user'));
		auth.status = true;
	} else {
		auth = {
			email: '',
			password: '',
			avatar: '',
			url: '',
			status: false,
			agreeTOS: true
		};
	}

	var appData = {
		sections: sections,
		state: {
			viewMode: viewMode,
			appBar: 'default',
			appBarColor: 'white'
		},
		auth: auth,
		loading: false

	};
	return appData;
});;adhApp.controller('articleCtrl', function($scope, apiFactory, $routeParams, $filter, $location) {

	$scope.appState.loading = true;

	$scope.appState.appBar = 'back';

	$scope.switchTab = function(tab) {
		$scope.activeTab = tab;
	};

	$scope.article = {};
	$scope.comments = [];

	if($routeParams.comments !== undefined && $routeParams.comments === 'comments') {
		$scope.activeTab = 'comments';
	} else {
		$scope.activeTab = 'article';
	}

	$scope.tabShadow = false;

	$(window).scroll(function() {
		if ($(window).scrollTop() > 50) {
			$scope.$apply(function() {
				$scope.tabShadow = true;
			});
		} else {
			$scope.$apply(function() {
				$scope.tabShadow = false;
			});
		}
	});

	apiFactory.getContent($routeParams.identifier).success(function(data) {
		var article = data[0];

// format date
article.publishDate = moment.unix(article.publishDate).format('Do MMMM YYYY, H:mm');

// add images in body with desired size
if (article.resources) {
	for (var key in article.resources.images) {
		article.resources.images[key].src = $filter('setImageSize')(article.resources.images[key].src, 'large');
		article.body = article.body.replace('{img:' + key + '}', '<img class="image inline" src="' + article.resources.images[key].src + '" />');
	}
}

// parse article for links that lead to other articles,
// remove the href so that they don't open externally, add ng-click with
// the openArticle() action which is afterwards compiled as angular by
// the bind-html-compile directive
var articleDOM = $($.parseHTML(article.body));
var domLinks = articleDOM.find('a');
for (var i = 0; i < domLinks.length; i++) {
	if($(domLinks[i]).attr('href').substring(0, 18) === 'http://adevarul.ro') {
		var href = $(domLinks[i]).attr('href');
		$(domLinks[i]).removeAttr('href');
		$(domLinks[i])
		.attr('ng-click', 'openArticleLink(' + '"' + href + '"' + ')')
		.attr('class', 'internal-article-link')
		.prepend('<dir-svg class="icon svg" src="img/icon-file.svg"></div>');
	}
}
var container = $('<div class="container"></div>').append(articleDOM);
var articleBody = container.prop('outerHTML');

// bind the article
$scope.article = article;
$scope.article.body = articleBody;

// handles links from articles
$scope.openArticleLink = function(link) {
	$location.path('/article/' + encodeURIComponent(link));
};

$scope.appState.loading = false;

});

apiFactory.comments.get($routeParams.identifier).success(function(data) {
	$scope.comments = data;
	$scope.appState.loading = false;
});

$scope.currentActiveReply = '';

$scope.openReply = function(commentId) {
	if ($scope.currentActiveReply === commentId) {
		$scope.currentActiveReply = '';
	} else {
		$scope.currentActiveReply = commentId;
	}
};

$scope.comment = {
	message: ''
};

if ($scope.isTablet.state === true) {
	$scope.lists = {};
	apiFactory.getBlogs().success(function(data) {
		$scope.lists.blogs = data.results;
	});
}

});;adhApp.controller('authCtrl', function($scope, apiFactory, dataFactory, $location, $routeParams) {

	$scope.authStep = 'initial';

	$scope.statusMessage = '';

	if($routeParams.step !== undefined) {
		$scope.authStep = $routeParams.step;
	}

	$scope.goToRegister = function() {
		$location.path('/auth/register');
	};

	$scope.registerAccount = function() {
		apiFactory.auth.register($scope.appData.auth.email, $scope.appData.auth.password, $scope.appData.auth.nume, $scope.appData.auth.prenume, $scope.appData.auth.agreeTOS).success(function(data) {
			if (data.ok === 'ok') { // our amazing API responses
				$scope.statusMessage = '';
				$scope.login();
			}
		}).error(function(data) {
			$scope.statusMessage = data.error;
		});
	};

	$scope.login = function() {
		apiFactory.auth.login($scope.appData.auth.email, $scope.appData.auth.password).success(function(data){
			localStorage.setItem('user', JSON.stringify(data));
			data.status = true;
			$scope.appData.auth = data;
			$scope.statusMessage = '';
			$location.path('/list').replace();
		}).error(function(data) {
			console.log('getshere');
			$scope.statusMessage = data.error;
		});
	};
	$scope.check = function() {
		apiFactory.auth.status().success(function(data) {
		});
	};
});;adhApp.controller('initCtrl', function($scope, dataFactory, apiFactory, $route, $location, $timeout) {
	// if the sections aren't stored in localstorage (see dataFactory)
	if(dataFactory.sections !== null) {
		$scope.sections = dataFactory.sections;
	} else {
		apiFactory.getSectionList().success(function(data) {
			localStorage.setItem('sections', JSON.stringify(data));
			$scope.sections = data;
		});
	}

	// bind the appState from the factory
	$scope.appState = dataFactory.state;

	// initial tablet state - checks below
	$scope.isTablet = {state: false};

	// device ready event
	deviceReady = function() {
		if ( $(window).outerWidth() < 480 ) {
			screen.lockOrientation('portrait');
		} else {
			screen.unlockOrientation();
			$scope.isTablet.state = true;
		}
	};

	// if this is a device, bind the device ready event, else, based on size
	// determine if it's a tablet or phone
	if (window.cordova) {
		document.addEventListener('deviceready', deviceReady, false);
	} else {
		if ( $(window).outerWidth() < 480 ) {
			$scope.isTablet.state = false;
		} else {
			$scope.isTablet.state = true;
		}
	}

	// bind the screen orientation
	$scope.orientation = screen.orientation;
	$scope.portrait = {state: null};
	if (screen.orientation.type === 'portrait-primary' || screen.orientation.type === 'portrait-secondary') {
		$scope.portrait.state = true;
	} else {
		$scope.portrait.state = false;
	}

	// on orientation change, scroll top the top and reload the content
	$(window).on('orientationchange', function() {
		$scope.mainArticleUI.closed = false;
		$('.slider-main').css('-webkit-transform', 'translateY(0px)');
		$scope.$apply(function() {
			$scope.orientation = screen.orientation;
			if (screen.orientation.type === 'portrait-primary' || screen.orientation.type === 'portrait-secondary') {
				$scope.portrait.state = true;
			} else {
				$scope.portrait.state = false;
			}
		});
	});

	$scope.mainArticleUI = {
		closed: false,
		toggle: function() {
			if ($scope.mainArticleUI.closed) {
				$scope.mainArticleUI.closed = false;
				$('.slider-main').css('-webkit-transform', 'translateY(0px)');
			} else {
				$scope.mainArticleUI.closed = true;
				$('.slider-main').css('-webkit-transform', 'translateY(' + '-' + ($('.slider-main').height() - 103) + 'px' + ')');
			}
		}
	};

	$scope.closeMain = function() {
		if ($scope.isTablet.state) {
			$scope.mainArticleUI.closed = true;
			$('.slider-main').css('-webkit-transform', 'translateY(' + '-' + ($('.slider-main').height() - 103) + 'px' + ')');
		}
	};

	$scope.openMain = function() {
		if ($scope.isTablet.state) {
			$scope.mainArticleUI.closed = false;
			$('.slider-main').css('-webkit-transform', 'translateY(0px)');
		}
	};


	// initial body classes
	$scope.bodyClasses = '';

	// init search here for scope propagation in both header and view
	$scope.search = {
		term: ''
	};

	// method for opening articles, used in multiple views
	$scope.openArticle = function(article, comments) {
		$scope.appState.loading = true;
		if (comments !== undefined) {
			$location.path('/article/' + article.id + '/comments');
		} else {
			$location.path('/article/' + article.id);
		}
	};

	// method for opening videos
	$scope.openVideo = function(video) {
		$scope.appState.loading = true;
		$location.path('/video/' + video.id);
	};

	// go to an app uri
	$scope.goTo = function(url) {
		$location.path(url);
	};


	// check authentication with server on app load, first localStorage check is in dataFactory
	$scope.appData = {};
	apiFactory.auth.status().success(function(data) {
		dataFactory.auth.state = data.success;
		$scope.appData.auth = dataFactory.auth;
	// if user isn't logged in on the server, set status to false and remove the localStorage user data
	if(!data.success) {
		$scope.appData.auth.status = false;
		localStorage.removeItem('user');
	}
	});

	// currentCategory, currently used in app-bar for category colors
	$scope.routeParams = {};
	$scope.$on('$locationChangeSuccess', function() {
		$scope.routeParams = {
			category: $route.current.params.category,
			subcategory: $route.current.params.subcategory
		};
	});

	// navigation menu is initially closed
	$scope.appState.navMenu = false;
	$scope.appState.configMenu = false;

});;adhApp.controller('listingCtrl', function($scope, $filter, apiFactory, $routeParams, $location) {

	if ($routeParams.category === 'live') {
		$scope.appState.isLive = true;
	} else if ($routeParams.category === 'blogs') {
		$scope.appState.isBlog = true;
	} else if ($routeParams.category === 'latest') {
		$scope.appState.isLatest = true;
	}

	$scope.mainArticleUI.closed = false;

	$(window).scrollTop(0);

	$scope.appState.appBar = 'default';

	$scope.appState.loading = true;

	$scope.lists = {
		news: [],
		media: [],
		blogs: []
	};

	$scope.breadcrumb = {
		category: undefined,
		subcategory: undefined
	};

	var current = 'home';

	if ($scope.isTablet.state) {
		apiFactory.getBlogs().success(function(data) {
			$scope.lists.blogs = data.results;
		});

		if($routeParams.category === undefined) {
			apiFactory.getLive().success(function(data) {
				$scope.lists.media = data.results;
			});
		} else {
			apiFactory.getLive($routeParams.category).success(function(data) {
				$scope.lists.media = data.results;
			});
		}

	}



	// set image size according to listing template
	var imgSize = '';
	if ($scope.appState.viewMode === 'list') {
		imgSize = 'small';
	} else if ($scope.appState.viewMode === 'grid') {
		imgSize = 'medium';
	} else if ($scope.appState.viewMode === 'card') {
		imgSize = 'large';
	} else if ($scope.appState.viewMode === 'tablet') {
		imgSize = 'large';
	}


	// are we loading the main home page or a section

	var requestType = '';

	if ($routeParams.category === undefined) {

		$scope.breadcrumb.category = 'Populare';

		requestType = 'home';

	} else {

		$scope.breadcrumb = $routeParams;

		requestType = {
			category: $routeParams.category,
			subcategory: $routeParams.subcategory
		};

	}

	$scope.listVisible = {state: false};

	$scope.contentType = 'base';

	apiFactory.getSection(requestType).success(function(data) {
		if ($routeParams.category === 'live') {
			$scope.contentType = 'live';
		} else if ($routeParams.category === 'blogs') {
			$scope.contentType = 'blogs';
		} else {
			$scope.contentType = 'base';
		}

		if (data.results) {
			data.articles = data.results;
		}

		// define the main article, set large image size
		var mainArticles = data.articles.slice(0,3);
		if ($scope.contentType === 'base' || $scope.contentType === 'latest') {
			$filter('setImageSize')(mainArticles, 'huge');
		}

		$scope.mainArticles = mainArticles;

		// remove first item since it's the main article, filter for image sizes
		data.articles.splice(0,3);
		if ($scope.contentType === 'base' || $scope.contentType === 'latest') {
			$filter('setImageSize')(data.articles, imgSize);
		}

		$scope.lists.news = data.articles;
		$scope.appState.loading = false;

	});
});;adhApp.controller('routeCtrl', function(dataFactory, $location) {
	// route to the set view
	$location.path('/list').replace();
});;adhApp.controller('searchCtrl', function($scope, apiFactory, $location) {

	$scope.bodyClasses = 'search-page';

	$scope.appState.appBar = 'search';


	$scope.search.results = undefined;
	$scope.search.status = 'idle';
	$scope.search.msg = 'Scrie un termen pentru a afisa rezultate.';

	// watch for model changes, updates with debounce set in search-menu.html
	$scope.$watch('search.term', function (tmpStr) {
		if (!tmpStr || tmpStr.length === 0) {
			return 0;
		}
	// if searchStr is still the same..
	// go ahead and retrieve the data
	if (tmpStr === $scope.search.term) {
		$scope.search.results = {};
		$scope.search.status = 'searching';
		$scope.search.msg = '';
		$scope.appState.loading = true;
		apiFactory.search($scope.search.term).success(function(data) {
			if (data.numFound === 0) {
				$scope.search.results = [];
				$scope.search.msg = 'Nu exista rezultate.';
			} else {
				$scope.search.results = data.results;
			}
			$scope.search.status = '';
			$scope.appState.loading = false;
		}).error(function() {

		});
	}
	});

});;adhApp.controller('settingsCtrl', function($scope) {

	$scope.appState.appBar = 'back';

	$scope.switchView = function(mode) {
		$scope.appState.viewMode = mode;
		localStorage.setItem('viewMode', mode);
	};

});;adhApp.controller('videoCtrl', function($scope, apiFactory, $routeParams, $sce, $filter) {

	document.addEventListener('deviceready', function() {

		screen.unlockOrientation();

		$scope.appState.appBar = 'back';
		$scope.appState.appBarColor = 'black';

		$scope.article = {};

		$scope.trustSrc = function(src) {
			return $sce.trustAsResourceUrl(src);
		};

		var windowWidth = $(window).width() - 30;
		var windowHeight = $(window).height();

		$scope.sizes = {};

		$scope.sizes.vWidth = $(window).width() - 30;
		$scope.sizes.vHeight = Math.round(9/16 * $scope.sizes.vWidth);

		apiFactory.getContent($routeParams.identifier, $scope.sizes.vWidth, $scope.sizes.vHeight).success(function(data) {

			data[0].src = $filter('setVideoSize')(data[0].src, $('.tb-view-video .video').width() - 100, $('.tb-view-video .video').height() - 100);
			$scope.article = data[0];

			$scope.appState.loading = false;

		});


		$(window).on('orientationchange', function() {

			if (window.orientation === 90 || window.orientation === -90) {
				$scope.sizes.vWidth = windowHeight;
				$scope.sizes.vHeight = 200;
			} else {
				$scope.sizes.vWidth = windowWidth;
				$scope.sizes.vHeight = Math.round(9/16 * $scope.sizes.vWidth);
			}

			$('iframe').remove();

			apiFactory.getContent($routeParams.identifier, $scope.sizes.vWidth, $scope.sizes.vHeight).success(function(data) {

				console.log(data);

				data[0].src = $filter('setVideoSize')(data[0].src, $('.tb-view-video .video').width() - 100, $('.tb-view-video .video').height() - 100);
				$scope.article = data[0];

				var iframe = $('<iframe width="' + $scope.sizes.vWidth + '" height="' + $scope.sizes.vHeight + '" src="' + $scope.article.iframeSrc +'"></iframe>');

				$('.video .video').append(iframe);

				$scope.appState.loading = false;

			});

		});

		$scope.$on('$routeChangeStart', function(next, current) {
			screen.lockOrientation('portrait');
		});

	}, false);

});;adhApp.directive('bindHtmlCompile', ['$compile', function ($compile) {
	return {
		restrict: 'A',
		link: function (scope, element, attrs) {

			function getPosition(element) {

				var offset = element.offset();
				return {
					Y: offset.top - $(window).scrollTop(),
					X: offset.left - $(window).scrollLeft()
				};

			}

			scope.$watch(function () {
				return scope.$eval(attrs.bindHtmlCompile);
			}, function (value) {
				element.html(value);
				$compile(element.contents())(scope);

			});


		}
	};
}]);;adhApp.directive('dirAppBar', function($filter, $location, $window, apiFactory) {
	return {
		restrict: 'E',
		templateUrl: 'templates/modules/app-bar.html',
		replace: true,
		link: function(scope) {

			scope.goBack = function() {
				$window.history.back();
			};

			scope.goTo = function(path) {
				$location.path(path);
			};

			scope.toggleMenu = function(menu) {

				// this surely can be done better
				// config menu
				if (menu === 'config') {
					scope.appState.navMenu = false;
					scope.appState.modal = false;
					$location.path('settings');
				// nav menu
				} else if (menu === 'nav') {
					if(scope.appState.navMenu) {
						scope.appState.navMenu = false;
						scope.appState.modal = false;
						scope.appState.configMenu = false;
					} else {
						scope.appState.navMenu = true;
						scope.appState.modal = true;
						scope.appState.configMenu = false;
					}
				} else if (menu === 'search') {
					if(scope.appState.searchMenu) {
						scope.appState.searchMenu = false;
						scope.appState.modal = false;
					} else {
						scope.appState.searchMenu = true;
						scope.appState.modal = true;
					}
				}
			};

		}
	};
});;adhApp.directive('dirArticleTools', function($location, apiFactory) {
	return {
		restrict: 'E',
		replace: true,
		scope: {
			article: '=data',
			contentType: '=ctype',
			mini: '=mini'
		},
		templateUrl: 'templates/modules/article-tools.html',
		link: function(scope, element, attrs) {

			scope.tools = {
				status: false,
				toggle: function() {
					if (scope.tools.status === false) {
						scope.tools.status = true;
					} else {
						scope.tools.status = false;
					}
				}
			};

			if(scope.mini === undefined) {
				scope.tools.status = true;
			}

			scope.openArticle = function(articleId, comments) {
				if (comments !== undefined) {
					$location.path('/article/' + articleId + '/comments');
				} else {
					$location.path('/article/' + articleId);
				}
			};

			scope.voted = {
				up: false,
				down: false
			};

			scope.vote = function(identifier, karmaType) {
				apiFactory.postKarma(identifier, karmaType).success(function(data) {
					if(data !== undefined || data !== null) {
						if (karmaType === true) {
							scope.voted.up = true;
							scope.voted.down = false;
						} else {
							scope.voted.down = true;
							scope.voted.up = false;
						}
					}
				}).error(function(data) {
					$location.path('auth');
				});
			};

			scope.share = function(message, title, image, link) {
				document.addEventListener("deviceready", function () {
					plugins.socialsharing.share(message, title, image, link);
				}, false);
			};

			scope.shareViaFacebook = function(url) {
				document.addEventListener("deviceready", function () {
					plugins.socialsharing.shareViaFacebook(null, null, url);
				}, false);
			};

			scope.openCardMenu = function(article) {
				if(article.cardMenu) {
					article.cardMenu = false;
				} else {
					article.cardMenu = true;
				}
			};

			scope.openInBrowser = function(url) {
				document.addEventListener("deviceready", function () {
					navigator.app.loadUrl(url, { openExternal: true });
				}, false);
			};

		}
	};
});;adhApp.directive('dirBreadcrumb', function($location, $timeout, apiFactory) {
	return {
		restrict: 'E',
		templateUrl: 'templates/modules/breadcrumb.html',
		link: function(scope, element, attrs) {

			scope.visible = false;

			$(window).scroll(function() {
				var distance = $(element).offset().top - $(window).scrollTop();
				if (distance < 45) {
					scope.$apply(function() {
						scope.visible = true;
					});
				} else if (distance > 45) {
					scope.$apply(function() {
						scope.visible = false;
					});
				}
			});
		}
	};
});;adhApp.directive('dirCommentForm', function(apiFactory) {
	return {
		restrict: 'E',
		replace: true,
		templateUrl: 'templates/modules/articles/comment-form.html',
		link: function(scope, element, attrs) {

			scope.comment.send = function() {
				// reply to a comment, currentActiveReply is the comment id set previously on open
				if(attrs.reply) {
					apiFactory.comments.post(scope.article.id, scope.comment.message, scope.currentActiveReply).success(function(data) {
						if(scope.comment.childs !== undefined) {
							scope.comment.childs.push(data);
						} else {
							scope.comment.childs = [data];
						}
					});
					// comment on the article
				} else {
					apiFactory.comments.post(scope.article.id, scope.comment.message).success(function(data) {
						scope.comments.push(data);
					});
				}
			};
		}
	};
});;adhApp.directive('elSize', ['$parse', function($parse) {
	return function(scope, elem, attrs) {

		if (scope.isTablet.state) {

		} else {
			scope.mainImage = {height:  0};
			var fn = $parse(attrs.elSize);
			scope.$watch(function() {
				return { width: elem.width(), height: elem.height() };
			}, function(contentHeight) {
				fn.assign(scope, contentHeight);
				// window height, minus black area, minus header
				scope.mainImage.height = $(window).height() - scope.contentHeight.height - 44;
			}, true);
		}

	};
}]);;adhApp.directive('dirInfoBox', function() {
	return {
		restrict: 'E',
		replace: false,
		templateUrl: 'templates/modules/info-box.html',
		link: function() {

		}
	};
});;adhApp.directive('dirLoading', function() {
	return {
		restrict: 'E',
		templateUrl: 'templates/modules/loading.html',
		replace: true,
		link: function() {

		}
	};
});;adhApp.directive('dirNavMenu', function($location, $filter, dataFactory, apiFactory) {
	return {
		restrict: 'E',
		replace: true,
		templateUrl: 'templates/modules/nav-menu.html',
		link: function(scope) {
			scope.appState.currentSection = false;
			scope.appState.currentSubSection = false;

			scope.openSubsection = function(data) {
				if (data === 'home') {
					scope.appState.isHome = true;
					scope.appState.isLive = false;
					scope.appState.isBlog = false;
					scope.appState.currentSection = '';
					scope.appState.modal = false;
					scope.appState.navMenu = false;
					scope.appState.isLatest = false;
					$location.path('/list').replace();
				} else if (data === 'live') {
					scope.appState.isHome = false;
					scope.appState.modal = false;
					scope.appState.navMenu = false;
					scope.appState.isBlog = false;
					scope.appState.isLatest = false;
					scope.appState.currentSection = false;
					scope.appState.currentSubSection = false;
					$location.path('/list/live');
				} else if (data === 'blogs') {
					scope.appState.isHome = false;
					scope.appState.modal = false;
					scope.appState.navMenu = false;
					scope.appState.isLive = false;
					scope.appState.isLatest = false;
					scope.appState.currentSection = false;
					scope.appState.currentSubSection = false;
					$location.path('/list/blogs');
				} else if (data === 'latest') {
					scope.appState.isHome = false;
					scope.appState.modal = false;
					scope.appState.navMenu = false;
					scope.appState.isBlog = false;
					scope.appState.isLive = false;
					scope.appState.currentSection = false;
					scope.appState.currentSubSection = false;
					$location.path('/list/latest');
				} else {
					scope.appState.isHome = false;
					scope.appState.isLive = false;
					scope.appState.isBlog = false;
					scope.appState.isLatest = false;
					// open category in menu
					scope.appState.currentSection = data;
				}
			};

			scope.loadListing = function(data) {
				var trimmedUrl = '';

				// it's the main section
				if(scope.appState.currentSection === data) {
					trimmedUrl = data.url.substring(0, data.url.length - 1);
					$location.path('/list' + trimmedUrl).replace();
				}

				scope.appState.currentSubSection = data;
				if (data === undefined) {
					$location.path('/list').replace();

				} else {

					 trimmedUrl = data.url.substring(0, data.url.length - 1);

					// navigate to subsection, remove trailing slash, angular misbehaves
					$location.path('/list' + trimmedUrl).replace();
					// close menu
				}
				scope.appState.modal = false;
				scope.appState.navMenu = false;
			};

			scope.openAuth = function() {
				$location.path('/auth');
				scope.appState.modal = false;
				scope.appState.navMenu = false;
			};


			scope.logout = function() {
				apiFactory.auth.logout().success(function(data) {
					scope.appData.auth = {};
					scope.appData.auth.status = false;
					localStorage.removeItem('user');
				});
			};

		}
	};
});;adhApp.directive('dirPage', function() {
	return {
		restrict: 'A',
		link: function(scope, element, attrs) {


		}
	};
});;adhApp.directive('dirShowAfter', function() {
	return {
		restrict: 'A',
		link: function(scope, element, attrs) {
			if (scope.$last) {
				// prevents flash of unstyled content
				scope.listVisible.state = true;
			}
		}
	};
});;adhApp.directive('dirSlider', function(apiFactory, $filter) {
	return {
		restrict: 'E',
		replace: true,
		scope: {
			gallery: '=gallery'
		},
		templateUrl: 'templates/modules/slider.html',
		link: function(scope, element) {
			if (scope.gallery !== undefined) {
				apiFactory.getContent(scope.gallery).success(function(gallery) {
					$filter('setImageSize')(gallery[0].images, 'large');
					scope.gallery = gallery[0];
				});
			}

		}
	};
});;// SVG items will only work properly if they are the only tag in the .svg file

adhApp.directive('dirSvg', function($http) {
	return {
		restrict: 'E',
		link: function(scope, element) {

			var $el = $(element);
			var elID = $el.attr('id');
			var elClass = $el.attr('class');
			var elURL = $el.attr('src');

			$http.get(elURL).success(function(data) {

				$svg = $($(data)[0]);

				if (typeof elID !== 'undefined') {
					$svg = $svg.attr('id', elID);
				}

				if (typeof elClass !== 'undefined') {
					$svg.attr('class', elClass+' replaced-svg');
				}

				$el.replaceWith($svg);

			});
		}
	};
});;adhApp.directive('dirArticleBlog', function() {
	return {
		restrict: 'E',
		replace: true,
		templateUrl: 'templates/modules/articles/article-blog.html',
		link: function(scope, element, attrs) {
		}
	};
});;adhApp.directive('dirArticleCard', function($location, $timeout, apiFactory) {
	return {
		restrict: 'E',
		replace: true,
		templateUrl: 'templates/modules/articles/article-card.html',
		link: function(scope, element, attrs) {
		}
	};
});;adhApp.directive('dirArticleGrid', function($location, $timeout, apiFactory) {
	return {
		restrict: 'E',
		replace: true,
		templateUrl: 'templates/modules/articles/article-grid.html',
		link: function(scope, element, attrs) {
		}
	};
});;adhApp.directive('dirArticleList', function($location, $timeout, apiFactory) {
	return {
		restrict: 'E',
		replace: true,
		templateUrl: 'templates/modules/articles/article-list.html',
		link: function(scope, element, attrs) {
		}
	};
});;adhApp.directive('dirArticleMain', function($location, $timeout, apiFactory) {
	return {
		restrict: 'E',
		replace: true,
		templateUrl: 'templates/modules/articles/article-main.html',
		link: function(scope, element, attrs) {

		}
	};
});;adhApp.directive('dirArticleMedia', function() {
	return {
		restrict: 'E',
		replace: true,
		templateUrl: 'templates/modules/articles/article-media.html',
		link: function(scope, element, attrs) {
		}
	};
});;adhApp.directive('dirComment', function($compile) {
	return {
		restrict: 'A',
		replace: true,
		templateUrl: 'templates/modules/articles/comment.html',
		link: function(scope, element, attrs) {
			if(scope.comment.childs && scope.comment.childs.length) {
				scope.responses = '<div ng-repeat="comment in comment.childs" dir-comment></div>';
			}
		}
	};
});;adhApp.filter('commentText', function () {

	return function (number) {

		if (number === 1)
			return number + " Comentariu";
		else {
			return number + " Comentarii";
		}

	};
});;adhApp.filter('scoreFilter', function () {

	return function (karma) {

		if (karma.score > 0) {
			return '+' + karma.score + " Scor" + " (" + karma.votes + " voturi)";
		} else {
			return karma.score + " Scor" + " (" + karma.votes + " voturi)";
		}

	};
});;adhApp.filter('setImageSize', function () {

	return function (data, size) {
		// define sizes, use window.devicePixelRatio later
		var retSize;
		if (size === 'huge') {
			retSize = '1024x661';
		} else if (size === 'large') {
			retSize = '627x0';
		} else if (size === 'medium') {
			retSize = '300x194';
		} else if (size === 'small') {
			retSize = '180x150';
		} else if (size === '50x50') {
			retSize = '50x50';
		} else if (size === '94x71') {
			retSize = '94x71';
		// custom size
		} else {
			retSize = size;
		}

		var extension = '';

		// set image sizes in an array
		if($.isArray(data)) {
			if (data[0].image !== undefined) {
				for (var i = 0; i < data.length; i++) {
					extension = data[i].image.substring(data[i].image.length - 4);
					data[i].image = data[i].image.substring(0, data[i].image.length - 11) + retSize + extension;
				}
			} else if (data[0].image === undefined && data[0].url !== undefined) {
				for (var j = 0; j < data.length; j++) {
					extension = data[j].url.substring(data[j].url.length - 4);
					data[j].url = data[j].url.substring(0, data[j].url.length - 11) + retSize + extension;
				}
			}

			return data;

		// if it's the image url
		} else if (typeof data === 'string') {
			extension = data.substring(data.length - 4);
			return data.substring(0, data.length - 11) + retSize + extension;
		} else {
			console.log('please pass an array or a image url string');
		}

	};
});;adhApp.filter('setVideoSize', function () {

	return function (data, width, height) {
		// fix string

		if (typeof data === 'string') {
			var stupidSlash = data.substr(24);
			var fixedURL = 'http://adevarul.ro/embed/' + stupidSlash;
			var croppedString = fixedURL.substring(0, data.length - 20);
			var size = '&width=' + width + '&height=' + height;
			return croppedString + size;
		} else {
			console.log('please pass an array or a image url string');
		}

	};
});;adhApp.filter('stripSlash', function () {
	return function (item) {
		return item.replace(/\//g, '');
	};
});;adhApp.filter('timeAgo', function () {

	return function (unixTime) {

		return moment.unix(unixTime).fromNow();

	};
});